In dit artikel wordt uitgelegd waarin de configuratie van Delivery Checkout bij gebruik met nShift Ship verschilt van de standaardconfiguratie.
In dit artikel:
- Een Delivery Checkout maken voor gebruik met nShift Ship
- Boeken en afdrukken met nShift Ship
- DeliveryCheckout API
Een Delivery Checkout maken voor gebruik met nShift Ship
Als Delivery Checkout nieuw voor je is, raden we aan om eerst deze artikelen te lezen:
Voordat je met de configuratie begint, moet je ten minste één afzender in je adresboek hebben. Raadpleeg Adresboek – nShift Delivery Help Center
Je moet ook je nShift Ship Actor ID en Key invoeren in het gedeelte Ship-gegevens bij je Afzender in nShift Delivery:
- Ga naar Onderhoud > Afzenders.
- Zoek je afzender of voeg een nieuwe afzender toe.
- Voer je Actor ID en Key in het gedeelte Ship-gegevens in.
Volg vervolgens de stappen in dit artikel: Een delivery checkout maken
Bekijk ook onze andere artikelen over
Delivery Checkout-proces met nShift Ship:
Boeken en afdrukken met nShift Ship
Je kunt zendingen met Ship boeken en afdrukken via de API of via bestandsimport.
Via API
Om zendingen te boeken en af te drukken via de Shipment Server API, gebruik je de prepare ID als OrderId-referentie om de actie SubmitShipment uit te voeren.
Bij het uitvoeren van SubmitShipment moet je ontbrekende verplichte verzendgegevens toevoegen, zoals pakketgegevens.
Lees meer over StoreOrder gebruiken om orders op te slaan voor import
Bestandsimport
Je kunt de prepare ID importeren en deze waarde invoeren bij Referenties > ShipAdvisor Reference, samen met verplichte verzendgegevens, zoals pakketgegevens.
Ga hier naar de Ship Help.
DeliveryCheckoutAPI
DeliveryCheckout API is een integratieservice voor communicatie tussen Delivery Checkout en je webshop. DeliveryCheckout API gebruikt een REST API-framework voor communicatie, met JSON als gegevensdrager, en biedt een aantal functies.
Je vindt alle algemene documentatie voor de DeliveryCheckoutAPI hier.
Bij gebruik in combinatie met nShift Ship zijn er enkele speciale scenario's, die we hieronder behandelen.
Een gedeeltelijke zending maken
POST /delivery-checkouts/{deliveryCheckoutId}/shipmentsMaakt een gedeeltelijke zending op basis van de leveringsoptie die de consument in de webshop heeft geselecteerd.
Dit eindpunt is verplicht.
Gebruik altijd de volledige Delivery Checkout-ID, omdat de versie van Delivery Checkout in de ID is opgenomen.
URI-parameters
| deliveryCheckoutId | string | De Delivery Checkout-ID die door het GET-verzoek wordt geretourneerd | Verplicht |
| returnShipmentData | boolean | Verzendgegevens worden in het antwoord geretourneerd. | Optioneel |
Voorbeeld van body
{
"selectedOptionId": "3e01c458-b4fb-4a15-9468-f9179a516a0c",
"language": "en",
"orderNo": "order number 123",
"prepareId": "test34",
"receiver": {
"name": "Testname",
"address1": "Testaddress 1",
"zipCode": "1080",
"city": "Ixelles",
"country": "BE",
"mobile": "0733000000",
"email": "email2@example.com"
},
"agent": {
"quickId": "19172",
"name": "DISTRIBUTEUR TRIBES BXL CN",
"address1": "Avenue Louise 279",
"address2": null,
"zipCode": "1050",
"city": "Bruxelles",
"state": null,
"country": "BE",
"mapLongitude": 4.36706,
"mapLatitude": 50.82386,
"phone": null,
"email": null
}
}
Voorbeeld van antwoord
{
"sourceSystem": "DH",
"serviceId": "DH:7132",
"optionTitle": "PostNord Varubrev 1:a klass (7132)",
"serviceCaption": "PostNord Varubrev 1:a klass (7132)",
"addons": []
}
Raadpleeg de referentiehandleiding voor eigenschappen voor een beschrijving van de eigenschappen.
Raadpleeg voor het schema en testen https://api.unifaun.com/rs-docs/ en ga naar /delivery-checkouts/{deliveryCheckoutId}/shipments POST.
Een gedeeltelijke zending ophalen
GET /delivery-checkout-shipments/{prepareId}Haalt een eerder gemaakte gedeeltelijke zending op.
URI-parameters
| prepareId | string | Identificatie van de gedeeltelijke zending. | Verplicht |
Voorbeeld van antwoord
{
"serviceId": "DCTEST",
"serviceTitle": "Delivery Checkout Test Service",
"sourceSystem": "UO",
"orderNo": "order number 123",
"prepareId": "123",
"sender": {
"quickId": "1",
"name": "nShift AB",
"address1": "Skeppsbron 5-6",
"postalCode": "41121",
"city": "GÖTEBORG",
"country": "SE",
"phone": "+46 31 725 35 00",
"email": "email1@example.com"
},
"receiver": {
"name": "nShift AB",
"address1": "Tegnérgatan 34",
"postalCode": "11359",
"city": "STOCKHOLM",
"country": "SE",
"phone": "+46 8 34 35 15",
"email": "email2@example.com"
}
}Raadpleeg de referentiehandleiding voor eigenschappen voor een beschrijving van de eigenschappen.
Raadpleeg voor het schema en testen https://api.unifaun.com/rs-docs/ en ga naar /delivery-checkout-shipments/{prepareId} GET.
Een gedeeltelijke zending verwijderen
DELETE /delivery-checkout-shipments/{prepareId}Verwijdert een gedeeltelijke zending.
Wanneer de gedeeltelijke zending is verwijderd, kan de prepare ID opnieuw worden gebruikt voor nieuwe gedeeltelijke zendingen.
URI-parameters
| prepareId | string | Identificatie van de gedeeltelijke zending | Verplicht |
Wanneer een gedeeltelijke zending succesvol is verwijderd, wordt er geen response body geretourneerd.
Raadpleeg de referentiehandleiding voor eigenschappen voor een beschrijving van de eigenschappen.
Raadpleeg voor het schema en testen https://api.unifaun.com/rs-docs/ en ga naar /delivery-checkout-shipments/{prepareId} DELETE.
Het bronsysteem van de service ophalen
GET /delivery-checkout-shipments/{prepareId}/source-systemHaalt het bronsysteem op waaruit de service van de gedeeltelijke zending afkomstig is.
Handig wanneer alleen de prepare ID bekend is en de Delivery Checkout-configuratie opties bevat met services uit meerdere bronsystemen.
URI-parameters
| prepareId | string | Identificatie van de gedeeltelijke zending. | Verplicht |
Raadpleeg de referentiehandleiding voor eigenschappen voor een beschrijving van de eigenschappen.
Raadpleeg voor het schema en testen https://api.unifaun.com/rs-docs/ en ga naar /delivery-checkout-shipments/{prepareId}/source-system GET.